## $Id: utils.py 7365 2011-12-17 18:47:57Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper utilities for SIRP.
"""
import grok
import smtplib
import string
from random import SystemRandom as r
from email.mime.text import MIMEText
from waeup.sirp.interfaces import ISIRPUtils

class SIRPUtils(grok.GlobalUtility):
    """A collection of methods subject to customization.
    """
    grok.implements(ISIRPUtils)

    def sendMail(self,fullname,username,usertype,portal,body,
                 email_from,email_to,subject):
        """Send an email with data provided by forms.
        """
        config = grok.getSite()['configuration']
        text = """Fullname: %s
User Id: %s
User Type: %s
Portal: %s

%s
"""
        msg = MIMEText(text % (fullname,username,usertype,portal,body))
        msg['From'] = '%s <%s>' % (fullname,email_from)
        msg['To'] = email_to
        msg['Subject'] = subject
        server = smtplib.SMTP(config.smtp_server)
        if config.smtp_requires_login:
            server.login(config.smtp_username,config.smtp_password)
        try:
            server.sendmail(email_from,email_to,msg.as_string())
        except:
            return False
        server.quit()
        return True

    def fullname(self,firstname,lastname,middlename=None):
        # We do not necessarily have the middlename attribute
        if middlename:
            return string.capwords(
                '%s %s %s' % (firstname, middlename, lastname))
        else:
            return string.capwords(
                '%s %s' % (firstname, lastname))

    def genPassword(self, length=8, chars=string.letters + string.digits):
        return ''.join([r().choice(chars) for i in range(length)])

    def sendPassword(self,fullname,msg,username,password,login_url,
                 email_to,subject):
        """Send an email with user credentials.
        """
        config = grok.getSite()['configuration']
        text = """Dear %s,

%s
Student Registration and Information Portal of
%s

Your user name is: %s
Your password is: %s
Login page: %s

Please remember your user name and keep
your password secret!

Regards
"""
        msg = MIMEText(text % (fullname,msg,config.name,username,password,login_url))
        msg['From'] = '%s <%s>' % (config.name_admin,config.email_admin)
        msg['To'] = email_to
        msg['Subject'] = subject
        server = smtplib.SMTP(config.smtp_server)
        if config.smtp_requires_login:
            server.login(config.smtp_username,config.smtp_password)
        try:
            server.sendmail(config.email_admin,email_to,msg.as_string())
        except:
            return False
        server.quit()
        return True

